# User Guide

```{toctree}
:maxdepth: 1
:hidden:

install
quickstart
reference/index
```

This documentation is aimed at end-users, i.e. authors of map viewer libraries for
Jupyter.

👈 Use the navigation on the left to continue!
